==> odoo14_addon_l10n_br_repair-14.0.1.0.1.dev3-py3-none-any.whl: odoo/addons/l10n_br_repair/models/fiscal_line_mixin.py <==
# Copyright 2021 - TODAY, Marcel Savegnago - Escodoo
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from odoo import api, fields, models

import odoo.addons.decimal_precision as dp


class FiscalLineMixin(models.AbstractModel):
    _name = "l10n_br_repair.fiscal.line.mixin"
    _inherit = ["l10n_br_fiscal.document.line.mixin"]
    _description = "Fiscal Line Mixin"

    @api.model
    def _default_fiscal_operation(self):
        return self.env.user.company_id.repair_fiscal_operation_id

    fiscal_operation_id = fields.Many2one(
        comodel_name="l10n_br_fiscal.operation",
        default=_default_fiscal_operation,
        domain=lambda self: self._fiscal_operation_domain(),
    )

    price_gross = fields.Monetary(
        compute="_compute_price_subtotal",
        string="Gross Amount",
        default=0.00,
    )

    price_total = fields.Monetary(
        compute="_compute_price_subtotal",
        string="Price Total",
        default=0.00,
    )

    price_subtotal = fields.Float(
        "Subtotal",
        compute="_compute_price_subtotal",
        digits=dp.get_precision("Account"),
    )

    @api.model
    def _fiscal_operation_domain(self):
        domain = [("state", "=", "approved")]
        return domain

    def _prepare_invoice_line(self):
        self.ensure_one()
        product = self.product_id.with_company(self.company_id.id)
        partner_invoice = self.repair_id.partner_invoice_id or self.repair_id.partner_id
        fpos = self.env["account.fiscal.position"].get_fiscal_position(
            partner_invoice.id, delivery_id=self.repair_id.address_id.id
        )
        account = product.product_tmpl_id.get_product_accounts(fiscal_pos=fpos)[
            "income"
        ]
        res = {
            "name": self.name,
            "account_id": account.id,
            "quantity": self.product_uom_qty,
            "tax_ids": [(6, 0, self.tax_id.ids)],
            "product_uom_id": self.product_uom.id,
            "price_unit": self.price_unit,
            "product_id": self.product_id.id,
        }
        res.update(self._prepare_br_fiscal_dict())
        return res

    @api.onchange("fiscal_tax_ids")
    def _onchange_fiscal_tax_ids(self):
        super()._onchange_fiscal_tax_ids()
        self.tax_id |= self.fiscal_tax_ids.account_taxes(user_type="sale")
        if self.repair_id.fiscal_operation_id.deductible_taxes:
            self.tax_id |= self.fiscal_tax_ids.account_taxes(
                user_type="sale", deductible=True
            )

    @api.onchange("product_uom", "product_uom_qty")
    def _onchange_product_uom(self):
        """To call the method in the mixin to update
        the price and fiscal quantity."""
        self._onchange_commercial_quantity()

==> odoo14_addon_l10n_br_repair-14.0.1.0.4.dev3-py3-none-any.whl: odoo/addons/l10n_br_repair/models/fiscal_line_mixin.py <==
# Copyright 2021 - TODAY, Marcel Savegnago - Escodoo
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from odoo import api, fields, models

import odoo.addons.decimal_precision as dp


class FiscalLineMixin(models.AbstractModel):
    _name = "l10n_br_repair.fiscal.line.mixin"
    _inherit = ["l10n_br_fiscal.document.line.mixin"]
    _description = "Fiscal Line Mixin"

    @api.model
    def _default_fiscal_operation(self):
        return self.env.user.company_id.repair_fiscal_operation_id

    fiscal_operation_id = fields.Many2one(
        comodel_name="l10n_br_fiscal.operation",
        default=_default_fiscal_operation,
        domain=lambda self: self._fiscal_operation_domain(),
    )

    price_gross = fields.Monetary(
        compute="_compute_price_subtotal",
        string="Gross Amount",
        default=0.00,
    )

    price_total = fields.Monetary(
        compute="_compute_price_subtotal",
        default=0.00,
    )

    price_subtotal = fields.Float(
        "Subtotal",
        compute="_compute_price_subtotal",
        digits=dp.get_precision("Account"),
    )

    @api.model
    def _fiscal_operation_domain(self):
        domain = [("state", "=", "approved")]
        return domain

    def _prepare_invoice_line(self):
        self.ensure_one()
        product = self.product_id.with_company(self.company_id.id)
        partner_invoice = self.repair_id.partner_invoice_id or self.repair_id.partner_id
        fpos = self.env["account.fiscal.position"].get_fiscal_position(
            partner_invoice.id, delivery_id=self.repair_id.address_id.id
        )
        account = product.product_tmpl_id.get_product_accounts(fiscal_pos=fpos)[
            "income"
        ]
        res = {
            "name": self.name,
            "account_id": account.id,
            "quantity": self.product_uom_qty,
            "tax_ids": [(6, 0, self.tax_id.ids)],
            "product_uom_id": self.product_uom.id,
            "price_unit": self.price_unit,
            "product_id": self.product_id.id,
        }
        res.update(self._prepare_br_fiscal_dict())
        return res

    @api.onchange("fiscal_tax_ids")
    def _onchange_fiscal_tax_ids(self):
        result = super()._onchange_fiscal_tax_ids()
        self.tax_id |= self.fiscal_tax_ids.account_taxes(user_type="sale")
        if self.repair_id.fiscal_operation_id.deductible_taxes:
            self.tax_id |= self.fiscal_tax_ids.account_taxes(
                user_type="sale", deductible=True
            )
        return result

    @api.onchange("product_uom", "product_uom_qty")
    def _onchange_product_uom(self):
        """To call the method in the mixin to update
        the price and fiscal quantity."""
        self._onchange_commercial_quantity()
